﻿using System;
using EngineTuneControl.KSPPluginFramework;
using EngineTuneControl.ToolBar;
using UnityEngine;

namespace EngineTuneControl
{
    [KSPAddon(KSPAddon.Startup.Flight, false)]
    [WindowInitials(Caption = "Throttle setup", ClampToScreen = true, DragEnabled = true)]
    class EngineTuneUI : MonoBehaviourWindow
    {
        private EngineTuneToolbar _control_toolbar;


        internal override void Awake()
        {
            WindowRect = new Rect(50, 50, 160, 50);

            Visible = !ToolbarManager.ToolbarAvailable;

            _control_toolbar = AddComponent<EngineTuneToolbar>();

            _control_toolbar.OnClick += _control_toolbar_OnClick;
        }

        void _control_toolbar_OnClick(object sender, EventArgs e)
        {
            Visible = !Visible;
        }

        internal override void DrawWindow(int id)
        {
            GUILayout.BeginVertical();

            TuneControlSettings.Instance.IsEnabled = GUILayout.Toggle(TuneControlSettings.Instance.IsEnabled, "Enable control");

            GUILayout.Label("Throttle divider");

            TuneControlSettings.Instance.EngineDividerValue = GUILayout.HorizontalSlider(TuneControlSettings.Instance.EngineDividerValue, 0, 0.01f);

            GUILayout.Label(TuneControlSettings.Instance.EngineDividerValue.ToString("#.###"));

            GUILayout.EndVertical();
        }

        internal override void Update()
        {
            base.Update();

            if (Event.current.alt)
            {
                if (Input.GetKeyUp(KeyCode.P))
                {
                    if (TuneControlSettings.Instance.EngineDividerValue < .01f)
                    {
                        TuneControlSettings.Instance.EngineDividerValue += .001f;
                    }

                    return;
                }
                if (Input.GetKeyUp(KeyCode.O))
                {
                    if (TuneControlSettings.Instance.EngineDividerValue > 0)
                    {
                        TuneControlSettings.Instance.EngineDividerValue -= .001f;
                    }

                    return;
                }
            }

            if (Input.GetKeyUp(KeyCode.O))
            {
                TuneControlSettings.Instance.IsEnabled = !TuneControlSettings.Instance.IsEnabled;
            }
        }


        internal override void OnDestroy()
        {
            _control_toolbar.OnClick -= _control_toolbar_OnClick;

            base.OnDestroy();
        }
    }
}
